pub const fn align_down(addr: u64, align: u64) -> u64Expand description
Align address downwards.
Returns the greatest x with alignment align so that x <= addr.
Panics if the alignment is not a power of two.
pub const fn align_down(addr: u64, align: u64) -> u64Align address downwards.
Returns the greatest x with alignment align so that x <= addr.
Panics if the alignment is not a power of two.