pub struct VirtAddrNotValid(pub u64);
A passed u64 was not a valid virtual address.
u64
This means that bits 48 to 64 are not a valid sign extension and are not null either. So automatic sign extension would have overwritten possibly meaningful bits. This likely indicates a bug, for example an invalid address calculation.
Contains the invalid address.
0: u64
TypeId
self
Returns the argument unchanged.
Calls U::from(self).
U::from(self)
That is, this conversion is whatever the implementation of [From]<T> for U chooses to do.
[From]<T> for U